@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Init;
 {
-  $Dist::Zilla::Plugin::Git::Init::VERSION = '1.113560';
+  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.025';
 }
 # ABSTRACT: initialize git repository on dzil new
 
@@ -40,6 +40,18 @@ has commit_message => (
     default => 'initial commit',
 );
 
+has commit => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 1,
+);
+
+has branch => (
+    is      => 'ro',
+    isa     => 'Str',
+    default => '',
+);
+
 has remotes => (
   is   => 'ro',
   isa  => 'ArrayRef[Str]',
@@ -58,7 +70,7 @@ sub mvp_aliases { return { config => 'config_entries', remote => 'remotes' } }
 sub after_mint {
     my $self = shift;
     my ($opts) = @_;
-    my $git = Git::Wrapper->new($opts->{mint_root});
+    my $git = Git::Wrapper->new("$opts->{mint_root}");
     $self->log("Initializing a new git repository in " . $opts->{mint_root});
     $git->init;
 
@@ -68,8 +80,16 @@ sub after_mint {
       $git->config($option, $value);
     }
 
-    $git->add($opts->{mint_root});
-    $git->commit({message => _format_string($self->commit_message, $self)});
+    $git->add("$opts->{mint_root}");
+    if ($self->commit) {
+      my $message = 'Made initial commit';
+      if (length $self->branch) {
+        $git->checkout('-b', $self->branch);
+        $message .= ' on branch ' . $self->branch;
+      }
+      $git->commit({message => _format_string($self->commit_message, $self)});
+      $self->log($message);
+    }
     foreach my $remoteSpec (@{ $self->remotes }) {
       my ($remote, $url) = split ' ', _format_string($remoteSpec, $self), 2;
       $self->log_debug("Adding remote $remote as $url");
@@ -79,16 +99,19 @@ sub after_mint {
 
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::Init - initialize git repository on dzil new
 
 =head1 VERSION
 
-version 1.113560
+version 2.025
 
 =head1 SYNOPSIS
 
@@ -96,6 +119,8 @@ In your F<profile.ini>:
 
     [Git::Init]
     commit_message = initial commit  ; this is the default
+    commit = 1                       ; this is the default
+    branch =                         ; this is the default (means master)
     remote = origin git@github.com:USERNAME/%{lc}N.git ; no default
     config = user.email USERID@cpan.org  ; there is no default
 
@@ -113,6 +138,14 @@ The plugin accepts the following options:
 =item * commit_message - the commit message to use when checking in
 the newly-minted dist. Defaults to C<initial commit>.
 
+=item * commit - if true (the default), commit the newly-minted dist.
+If set to a false value, add the files to the Git index but don't
+actually make a commit.
+
+=item * branch - the branch name under which the newly-minted dist is checked
+in (if C<commit> is true). Defaults to an empty string, which means that
+the Git default branch is used (master).
+
 =item * config - a config setting to make in the repository.  No
 config entries are made by default.  A setting is specified as
 C<OPTION VALUE>.  This may be specified multiple times to add multiple entries.
@@ -154,7 +187,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
