@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Push;
 {
-  $Dist::Zilla::Plugin::Git::Push::VERSION = '2.009';
+  $Dist::Zilla::Plugin::Git::Push::VERSION = '2.025';
 }
 # ABSTRACT: push current branch
 
@@ -25,9 +25,14 @@ use namespace::autoclean;
 with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::AfterRelease';
 with 'Dist::Zilla::Role::Git::Repo';
+with 'Dist::Zilla::Role::GitConfig';
 
 sub mvp_multivalue_args { qw(push_to) }
 
+sub _git_config_mapping { +{
+   push_to => '%{remote}s %{local_branch}s:%{remote_branch}s',
+} }
+
 # -- attributes
 
 has remotes_must_exist => ( ro, isa=>'Bool', default=>1 );
@@ -39,6 +44,19 @@ has push_to => (
   default => sub { [ qw(origin) ] },
 );
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ } qw(push_to remotes_must_exist),
+    };
+
+    return $config;
+};
 
 sub before_release {
     my $self = shift;
@@ -84,13 +102,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::Push - push current branch
 
 =head1 VERSION
 
-version 2.009
+version 2.025
 
 =head1 SYNOPSIS
 
